randoms
randoms is a crate to generate random catalogues of galaxies from redshift surveys in order to better model the selction function of these surveys and remove the underlying large-scale structure. This is essential for things like studying clustering and modelling the n(z) for group finding.
Modules
Functions
- generate_
randoms - Main function which generates the randoms vector of the survey (OPTIMIZED)